      subroutine dminfg(n,nx,ny,x,f,g,task,prob,par,w)
      character*(*) task, prob
      integer n, nx, ny
      double precision f, par
      double precision x(n), g(n), w(2*n)
c     *********
c
c     Subroutine dminfg
c
c     This subroutine selects the minimization problem from
c     the MINPACK-2 test problem collection specified by the
c     character variable prob.
c
c     The subroutine statement is
c
c       subroutine dminfg(n,nx,ny,x,f,g,task,prob,par,w)
c
c     where
c
c       n is an integer variable.
c         On entry n is the number of variables.
c         On exit n is unchanged.
c
c       nx is an integer variable.
c         On entry nx is the number of grid points in the first
c            coordinate direction.
c         On exit nx is unchanged.
c
c       ny is an integer variable.
c         On entry ny is the number of grid points in the second
c            coordinate direction. If the problem is formulated in
c            one spatial dimension, ny = 1.
c         On exit ny is unchanged.
c
c       x is a double precision array of dimension n.
c         On entry x specifies the vector x if the function
c            or the gradient need to be evaluated.
c            Otherwise x need not be specified.
c         On exit x is unchanged if the function or the gradient
c            need to be evaluated.
c            Otherwise x is set according to task.
c
c       f is a double precision variable.
c         On entry f need not be specified.
c         On exit f is set to the function evaluated at x if
c            task = 'F' or 'FG'.
c
c       g is a double precision array of dimension n.
c         On entry g need not be specified.
c         On exit g contains the gradient evaluated at x if
c            task = 'G' or 'FG'.
c
c       task is a character*60 variable.
c         On entry task specifies the action of the subroutine:
c
c            task               action
c            ----               ------
c             'F'     Evaluate the function at x.
c             'G'     Evaluate the gradient vector at x.
c             'FG'    Evaluate the function and the gradient at x.
c             'XS'    Set x to the standard starting point xs.
c             'XL'    Set x to the lower bound xl.
c             'XU'    Set x to the upper bound xu.
c
c         On exit task is unchanged.
c
c       prob is a character*6 variable.
c         On entry prob specifies the problem.
c         On exit prob is set to 'ERROR' if prob is not an
c            acceptable problem name. Otherwise prob is unchanged.
c
c       par is a double precision variable.
c         On entry par specifies a probem-dependent parameter.
c         On exit par is unchanged.
c
c       w is a double precision array of dimension 2*n.
c
c     Subprograms called
c
c       MINPACK-2 ... deptfg, dglfg, dgl2fg, dmsafg, dmsabc,
c                     dljcfg, dodcfg, dpjbfg, dsscfg
c
c     MINPACK-2 Project. January 1995.
c     Argonne National Laboratory.
c     Brett M. Averick and Jorge J. More'.
c
c     **********
      double precision b
      parameter (b=10.0d0)

      external deptfg, dglfg, dgl2fg, dmsafg, dmsabc, dljcfg, dodcfg,
     +         dpjbfg, dsscfg

c     Select a problem

      if (prob .eq. 'DEPT') then
         call deptfg(nx,ny,x,f,g,task,par)
      else if (prob .eq. 'DPJB') then
         call dpjbfg(nx,ny,x,f,g,task,par,b)
      else if (prob .eq. 'DMSA') then
         call dmsabc(nx,ny,w(1),w(nx+3),w(2*nx+5),w(2*nx+ny+7))
         call dmsafg(nx,ny,x,f,g,task,w(1),w(nx+3),w(2*nx+5),
     +               w(2*nx+ny+7))
      else if (prob .eq. 'DODC') then
         call dodcfg(nx,ny,x,f,g,task,par)
      else if (prob .eq. 'DGL1') then
         call dgl1fg(n,x,f,g,task,par)
      else if (prob .eq. 'DSSC') then
         call dsscfg(nx,ny,x,f,g,task,par)
      else if (prob .eq. 'DLJ2') then
         call dljcfg(n,x,f,g,task,2,n/2)
      else if (prob .eq. 'DLJ3') then
         call dljcfg(n,x,f,g,task,3,n/3)
      else if (prob .eq. 'DGL2') then
         call dgl2fg(nx,ny,x,f,g,task,w,int(par))
      else
         prob = 'ERROR'
      end if

      end
